@@ -77,7 +77,7 @@ void cramer_vonMises_grid(int *p, double *U, int *n, double *V, int *m,
 }
 
 /**
- * Multiplier bootstrap for the GoF testing
+ * Multiplier bootstrap for the GoF testing: R's  gofCopula(*, simulation="mult")
  *
  * @param p dimension
  * @param U pseudo-observations (n x p)
@@ -85,7 +85,7 @@ void cramer_vonMises_grid(int *p, double *U, int *n, double *V, int *m,
  * @param G grid (g x p)
  * @param g grid size
  * @param influ influence matrix (g x n)
- * @param N number of multiplie replications
+ * @param N number of multiplier replications
  * @param s0 N replications of the test statistic
  * @author Ivan Kojadinovic
  */
@@ -93,24 +93,22 @@ void multiplier(int *p, double *U, int *n, double *G, int *g,
 		double *influ, int *N, double *s0)
 {
   int i, j, k, l, ind;
-  double *influ_mat = Calloc((*n) * (*g), double);
-  double *random = Calloc(*n, double);
-  double *v1 = Calloc(*p, double);
-  double *v2 = Calloc(*p, double);
-  double *der = Calloc(*p, double);
-  double mean, process, invsqrtn = 1.0/sqrt(*n);
+  double invsqrtn = 1.0/sqrt(*n);
+  double *influ_mat = Calloc((*n) * (*g), double),
+    *v1  = Calloc(*p, double), *v2 = Calloc(*p, double),
+    *der = Calloc(*p, double);
 
   /* influence matrix */
   for (j = 0; j < *g; j++) /* loop over the grid points */
     {
       /* derivatives wrt args */
       for (k = 0; k < *p; k++)
-	{
+        {
 	  v1[k] = G[j + k * (*g)];
 	  v2[k] = v1[k];
-	}
+        }
       for (k = 0; k < *p; k++)
-	{
+        {
 	  v1[k] += invsqrtn;
 	  v2[k] -= invsqrtn;
 	  der[k] = der_multCn(U, *n, *p, v1, v2, 2 * invsqrtn);
@@ -119,7 +117,7 @@ void multiplier(int *p, double *U, int *n, double *G, int *g,
 	}
 
       for (i = 0; i < *n; i++) /* loop over the data */
-	{
+        {
 	  influ_mat[i + j * (*n)] = 0.0;
 	  ind = 1;
 	  for (k = 0; k < *p; k++)
@@ -127,20 +125,24 @@ void multiplier(int *p, double *U, int *n, double *G, int *g,
 	      ind *= (U[i + k * (*n)] <= G[j + k * (*g)]);
 	      influ_mat[i + j * (*n)] -= der[k] * (U[i + k * (*n)] <= G[j + k * (*g)]);
 	    }
-	  influ_mat[i + j * (*n)] += ind; /* - influ[j + i * (*g)];*/
-	  influ[j + i * (*g)] *= invsqrtn;
+	  influ_mat[i + j * (*n)] += ind; /* - influ[j + i * (*g)]; */
+	  influ    [j + i * (*g)] *= invsqrtn;
 	  influ_mat[i + j * (*n)] *= invsqrtn;
 	}
     }
+  Free(v1);
+  Free(v2);
+  Free(der);
+
+  double *random = Calloc(*n, double);
 
   GetRNGstate();
-
   /* generate N approximate realizations */
-  for (l=0;l<*N;l++)
+  for (l=0; l < *N; l++)
     {
       /* generate n variates */
-      mean = 0.0;
-      for (i=0;i<*n;i++)
+      double mean = 0.0;
+      for (i=0; i<*n; i++)
 	{
 	  random[i] = norm_rand(); /*(unif_rand() < 0.5) ? -1.0 : 1.0 ;*/
 	  mean += random[i];
@@ -149,10 +151,10 @@ void multiplier(int *p, double *U, int *n, double *G, int *g,
 
       /* realization number l */
       s0[l] = 0.0;
-      for (j=0;j<*g;j++)
+      for (j=0; j<*g; j++)
 	{
-	  process = 0.0;
-	  for (i=0;i<*n;i++)
+	  double process = 0.0;
+	  for (i=0; i<*n; i++)
 	    process += (random[i] - mean) * influ_mat[i + j * (*n)]
 	      - random[i] * influ[j + i * (*g)];
 	  s0[l] += process * process;
@@ -164,9 +166,6 @@ void multiplier(int *p, double *U, int *n, double *G, int *g,
 
   Free(influ_mat);
   Free(random);
-  Free(v1);
-  Free(v2);
-  Free(der);
 }
 
 /// Goodness-of-fit tests for extreme-value copulas
@@ -184,24 +183,24 @@ void multiplier(int *p, double *U, int *n, double *G, int *g,
  * @param stat value of the test statistic
  * @author Ivan Kojadinovic
  */
-void cramer_vonMises_Pickands(int *n, int *m, double *S,
+void cramer_vonMises_Pickands(int n, int m, double *S,
 			      double *T, double *Atheta,
 			      double *stat) {
   double t, Ac, Au, dc, du,
-    invA0 = biv_invAP(*n, S, T, 0.0);
+    invA0 = biv_invAP(n, S, T, 0.0);
 
   stat[0] = 0.0; stat[1] = 0.0;
-  for (int i = 0; i < *m; i++) {
-      t = (double)i/(double)(*m);
-      Au = biv_invAP(*n, S, T, t);
+  for (int i = 0; i < m; i++) {
+      t = (double)i/(double)(m);
+      Au = biv_invAP(n, S, T, t);
       Ac = Au - invA0 + 1.0; // correction
       du = 1 / Au - Atheta[i];
       dc = 1 / Ac - Atheta[i];
       stat[0] += dc * dc;
       stat[1] += du * du;
     }
-  stat[0] = stat[0] * (double)(*n) / (double)(*m);
-  stat[1] = stat[1] * (double)(*n) / (double)(*m);
+  stat[0] = stat[0] * (double)(n) / (double)(m);
+  stat[1] = stat[1] * (double)(n) / (double)(m);
 }
 
 /**
@@ -217,24 +216,24 @@ void cramer_vonMises_Pickands(int *n, int *m, double *S,
  * @param stat value of the test statistic
  * @author Ivan Kojadinovic
  */
-void cramer_vonMises_CFG(int *n, int *m, double *S,
+void cramer_vonMises_CFG(int n, int m, double *S,
 			 double *T, double *Atheta,
 			 double *stat) {
   double t, Au, Ac, dc, du,
-    logA0 = biv_logACFG(*n, S, T, 0.0);
+    logA0 = biv_logACFG(n, S, T, 0.0);
 
   stat[0] = 0.0; stat[1] = 0.0;
-  for (int i = 0; i < *m; i++) {
-      t = (double) i / (double) (*m);
-      Au = biv_logACFG(*n, S, T, t);
+  for (int i = 0; i < m; i++) {
+      t = (double) i / (double) (m);
+      Au = biv_logACFG(n, S, T, t);
       Ac = Au - logA0; // correction
       dc = exp(Ac) - Atheta[i];
       du = exp(Au) - Atheta[i];
       stat[0] += dc * dc;
       stat[1] += du * du;
     }
-  stat[0] = stat[0] * (double)(*n)/(double)(*m);
-  stat[1] = stat[1] * (double)(*n)/(double)(*m);
+  stat[0] = stat[0] * (double)(n)/(double)(m);
+  stat[1] = stat[1] * (double)(n)/(double)(m);
 }
 
 /**
@@ -256,7 +255,7 @@ void cramer_vonMises_Afun(int *n, int *m, double *S,
 			  double *stat, int *CFG)
 {
   if (*CFG)
-    cramer_vonMises_CFG(n, m, S, T, Atheta, stat);
+    cramer_vonMises_CFG(*n, *m, S, T, Atheta, stat);
   else
-    cramer_vonMises_Pickands(n, m, S, T, Atheta, stat);
+    cramer_vonMises_Pickands(*n, *m, S, T, Atheta, stat);
 }
